/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2013  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 3.88g                                            *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for MSC ModSDKM16C-CM16C62P development kit
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "RTOS.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

/****** Addresses of sfrs and peripheral identifiers ****************/
#define P7  (*(volatile unsigned char*)0x3ED)   /* Port P7 register */
#define P7D (*(volatile unsigned char*)0x3EF)   /* Port P7 direction register */

/****** Assign LEDs to Ports ****************************************/
#define LED0_BIT  (0)
#define LED1_BIT  (3)
#define LED_MASK_ALL ((1 << LED0_BIT) | (1 << LED1_BIT))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Initially switch off LEDs
  //
  P7 = 0;
  //
  // Enable output port for LEDS
  //
  P7D |= LED_MASK_ALL;
}

/*********************************************************************
*
*       LED switching routines
*       LEDs are switched on with low level on port lines
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    P7 |= (1 << LED0_BIT);
  } else if (Index == 1) {
    P7 |= (1 << LED1_BIT);
  }
}

void BSP_ClrLED(int Index) {
  if (Index == 0) {
    P7 &= ~(1 << LED0_BIT);
  } else if (Index == 1) {
    P7 &= ~(1 << LED1_BIT);
  }
}

void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    P7 ^= (1 << LED0_BIT);
  } else if (Index == 1) {
    P7 ^= (1 << LED1_BIT);
  }

}

/****** EOF *********************************************************/


