/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2013  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 3.88g                                            *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : for MSC ModSDKM16C-CR8C1B development kit
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "RTOS.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

/****** Addresses of sfrs and peripheral identifiers ****************/
#define _P3  (*(volatile unsigned char*)0xE5)   /* Port P7 register */
#define _P3D (*(volatile unsigned char*)0xE7)   /* Port P7 direction register */

#define _LED_PORT     (_P3)
#define _LED_PORT_DIR (_P3D)

/****** Assign LEDs to Ports ****************************************/
#define _LED0_BIT  (4)
#define _LED1_BIT  (5)
#define _LED_MASK_ALL ((1 << _LED0_BIT) | (1 << _LED1_BIT))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Initially switch off LEDs
  //
  _LED_PORT &= ~(_LED_MASK_ALL);
  //
  // Enable output port for LEDS
  //
  _LED_PORT_DIR |= _LED_MASK_ALL;
}

/*********************************************************************
*
*       LED switching routines
*/
void BSP_SetLED(int Index) {
  _LED_PORT |= (1 << (Index+4));
}

void BSP_ClrLED(int Index) {
  _LED_PORT &= ~(1 << (Index+4));
}

void BSP_ToggleLED(int Index) {
  _LED_PORT ^= (1 << (Index+4));
}

/****** EOF *********************************************************/


